@@ -1,11 +1,11 @@
 package DBIx::SchemaChecksum;
 
+# ABSTRACT: Manage your datebase schema via checksums
+our $VERSION = '1.103'; # VERSION
+
 use 5.010;
 use Moose;
 
-# ABSTRACT: Manage your datebase schema via checksums
-our $VERSION = '1.102';
-
 use DBI;
 use Digest::SHA1;
 use Data::Dumper;
@@ -295,7 +295,7 @@ DBIx::SchemaChecksum - Manage your datebase schema via checksums
 
 =head1 VERSION
 
-version 1.102
+version 1.103
 
 =head1 SYNOPSIS
 
@@ -874,7 +874,7 @@ writing proper docs.
 
 =item *
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =item *
 
@@ -888,7 +888,7 @@ Klaus Ita <koki@worstofall.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Thomas Klausner, Maroš Kollár, Klaus Ita.
+This software is copyright (c) 2012 - 2021 by Thomas Klausner, Maroš Kollár, Klaus Ita.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
