@@ -1,7 +1,9 @@
 package DBIx::SchemaChecksum::App::ApplyChanges;
-use 5.010;
 
 # ABSTRACT: Apply changes based on current checksum
+our $VERSION = '1.103'; # VERSION
+
+use 5.010;
 
 use MooseX::App::Command;
 extends qw(DBIx::SchemaChecksum::App);
@@ -160,7 +162,7 @@ DBIx::SchemaChecksum::App::ApplyChanges - Apply changes based on current checksu
 
 =head1 VERSION
 
-version 1.102
+version 1.103
 
 =head1 DESCRIPTION
 
@@ -186,7 +188,7 @@ rolls back the last change (if your DB supports transactions...)
 
 =item *
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =item *
 
@@ -200,7 +202,7 @@ Klaus Ita <koki@worstofall.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Thomas Klausner, Maroš Kollár, Klaus Ita.
+This software is copyright (c) 2012 - 2021 by Thomas Klausner, Maroš Kollár, Klaus Ita.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
