@@ -1,7 +1,9 @@
 package DBIx::SchemaChecksum::App::Checksum;
-use 5.010;
 
 # ABSTRACT: get the current DB checksum
+our $VERSION = '1.103'; # VERSION
+
+use 5.010;
 
 use MooseX::App::Command;
 extends qw(DBIx::SchemaChecksum::App);
@@ -35,7 +37,7 @@ DBIx::SchemaChecksum::App::Checksum - get the current DB checksum
 
 =head1 VERSION
 
-version 1.102
+version 1.103
 
 =head1 DESCRIPTION
 
@@ -48,7 +50,7 @@ show the string dump on which the checksum is based.
 
 =item *
 
-Thomas Klausner <domm@cpan.org>
+Thomas Klausner <domm@plix.at>
 
 =item *
 
@@ -62,7 +64,7 @@ Klaus Ita <koki@worstofall.com>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2012 by Thomas Klausner, Maroš Kollár, Klaus Ita.
+This software is copyright (c) 2012 - 2021 by Thomas Klausner, Maroš Kollár, Klaus Ita.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
